#!/bin/bash

#shellcheck disable=SC1090,SC1091
source /service-fabric/modules/utils.sh

# Prints certificate SAN names and expiry date
function check_istio_certificate() {
    CERT_LOCATION="istio-cert.pem"

    section "Certificate Checks"
    if kubectl -n istio-system get secret istio-ingressgateway-certs &>/dev/null;
    then
        kubectl -n istio-system get secret istio-ingressgateway-certs -o jsonpath="{.data.tls\.crt}" | base64 -d > $CERT_LOCATION
        SAN_INGRESS=$(openssl x509 -noout -text -in $CERT_LOCATION | grep -oE '(DNS:|IP Address:)[^,]+')
        INGRESS_CERT_EXPIRY=$(openssl x509 -noout -enddate -in $CERT_LOCATION | cut -d "=" -f 2 )
        INGRESS_HOST=$(kubectl -n istio-system get gateway main-gateway -o jsonpath='{.spec.servers[?(@.port.name=="https")].hosts[0]}')

        if [[ "${SAN_INGRESS}" == *"${INGRESS_HOST}"* ]];
        then
            add_to_report info "Certificate is valid for the given host."
        else
            add_to_report warn "Certifiate is not valid for the given host. Certificate is valid for following host names : ${SAN_INGRESS}"
        fi

        if openssl x509 -checkend 0 -noout -in $CERT_LOCATION &>/dev/null
        then
            add_to_report info "Certificate not expired. Expiry Date : ${INGRESS_CERT_EXPIRY}"
        else
            add_to_report error "Certificate expired. Expiry Date : ${INGRESS_CERT_EXPIRY}"
        fi
    else
        add_to_report error "Certificate secret does not exist. HTTPS access to the cluster will not work." 
    fi
}

check_istio_certificate