#!/bin/bash

SCRIPT_DIR=$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)
export ALL_SUPPORT_BUNDLES_LOCATION=/tmp/uipath-support
export RUNTIME_IMAGE="registry.uipath.com/sf-k8-utils-rhel:0.8"

function set_runtime_image_offline(){
  [[ -z "$(kubectl -n docker-registry get pod -l=app=docker-registry -o name)" ]] && return
  TAG=$(kubectl -n docker-registry exec -it "$(kubectl -n docker-registry get pod -l=app=docker-registry -o name)" -- sh -c "ls /var/lib/registry/docker/registry/v2/repositories/sf-k8-utils-rhel/_manifests/tags 2>/dev/null | head -n 1")
  if [[ -n ${TAG} ]];
  then
    export RUNTIME_IMAGE="localhost:30071/sf-k8-utils-rhel:${TAG}"
  fi
}

function main() {
    set_runtime_image_offline
    \cp "${SCRIPT_DIR}/node-daemonset.yaml" "${SCRIPT_DIR}/node-daemonset-tmp.yaml"
    sed -i "s;IMAGE_PLACEHOLDER;${RUNTIME_IMAGE};" "${SCRIPT_DIR}/node-daemonset-tmp.yaml"
    kubectl apply -f "${SCRIPT_DIR}/node-daemonset-tmp.yaml"
    kubectl -n kube-system rollout status daemonset/support-root-container --timeout=60s
    support_pods=$(kubectl -n kube-system get pods -l app=support-root-container --field-selector status.phase=Running -o custom-columns=NAME:.metadata.name --no-headers)
    for pod in ${support_pods};
    do
        node_name=$(kubectl -n kube-system get pods "${pod}" -o custom-columns=NODE:.spec.nodeName --no-headers)
        echo "Generating RKE2 support bundle on $node_name"
        kubectl -n kube-system cp "${SCRIPT_DIR}/rke2-support-bundle.sh" "${pod}:/host/tmp/"
        BUNDLE_GENERATION_OUTPUT=$(kubectl -n kube-system exec -it "${pod}" -- chroot host bash /tmp/rke2-support-bundle.sh | grep "Created /tmp/" | tail -1 | xargs)
        bundle_name=$(echo "${BUNDLE_GENERATION_OUTPUT}" | cut -d '/' -f3 | tr -d '\r')
        echo "Bundle from $node_name is $bundle_name"
        kubectl -n kube-system cp "${pod}:host/tmp/${bundle_name}" "${ALL_SUPPORT_BUNDLES_LOCATION}/${bundle_name}"
    done
}

main
